==> grdesktop-0.20.tar.gz: grdesktop-0.20/src/global.h <==
/* grdesktop - gtk rdesktop frontend
 * Copyright (C) 2002 Thorsten Sauter <tsauter@gmx.net>
 *
 * $grdesktop: grdesktop/src/global.h,v 1.16 2003/11/07 12:41:20 tsauter Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifndef __CONFIG_H__
#define __CONFIG_H__

#include <gtk/gtk.h>
#include <gconf/gconf-client.h>
#include <stdlib.h>
#include <stdio.h>

#ifdef SHASH
#undef SHASH
#endif
#define SHASH(str) (gchar*)g_hash_table_lookup(config, str)

#ifdef iSHASH
#undef iSHASH
#endif
#define iSHASH(str) \
	(gint) \
	((SHASH(str) == NULL) ? 0 : \
	g_ascii_digit_value((char)(*SHASH(str))))

#ifdef setBHASH
#undef setBHASH
#endif
#define setBHASH(str, value) \
	if(SHASH(str) != NULL) { \
		g_hash_table_replace(config, str, \
			g_strdup_printf("%d", value)); \
	} else { \
		g_hash_table_insert(config, str, \
			g_strdup_printf("%d", value)); \
	}

#define COMMANDLINE "rdesktop"

#ifndef MAXHOSTNAMELEN
#define MAXHOSTNAMELEN 64		/* max length of hostname */
#endif

#define MAXHOSTS 10			/* maximum hosts to store */
#define PIXDIR DATADIR"/pixmaps/grdesktop"
#ifndef KBPATH
#define KBPATH "/usr/local/share/rdesktop/keymaps/"
#endif

#define GCONF_BASE "/apps/grdesktop/options"

GList *hostnames;
GList *rdp_protocols;
GList *screensize;
GList *colors;
GHashTable *config;
GConfClient *gcfg;

/* these widgets are used global */
GtkWidget *window_main;
GtkWidget *image_normal;
GtkWidget *image_process;
GtkWidget *box_server;
GtkWidget *box_option;
GtkWidget *connect_btn;
GtkWidget *cancel_btn;
GtkWidget *option_btn;
GtkWidget *combo_host;
GtkWidget *combo_host2;
GtkWidget *input_username;
GtkWidget *input_password;
GtkWidget *input_domain;
GtkWidget *check_savepw;
GtkWidget *menu_rdp_proto;
GtkObject *adj_screensize;
GtkWidget *scroll_screensize;
GtkWidget *geometry_label;
GtkWidget *colorsize_menu;
GtkWidget *colorsize_img;
GtkWidget *keymap;
GtkWidget *check_prog;
GtkWidget *program;
GtkWidget *ppath;
GtkWidget *check_bitmapupd;
GtkWidget *check_motionevt;
GtkWidget *check_hidewmdecoration;
GtkWidget *check_noencr;
GtkWidget *check_wmkeybindings;
GtkWidget *check_attconsole;
GtkWidget *clientname;

#endif /* __CONFIG_H__ */

==> grdesktop-0.22.tar.gz: grdesktop-0.22/src/global.h <==
/* grdesktop - gtk rdesktop frontend
 * Copyright (C) 2002 Thorsten Sauter <tsauter@gmx.net>
 *
 * $grdesktop: grdesktop/src/global.h,v 1.19 2003/11/17 16:21:00 tsauter Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifndef __CONFIG_H__
#define __CONFIG_H__

#include <gtk/gtk.h>
#include <gconf/gconf-client.h>
#include <stdlib.h>
#include <stdio.h>

#ifdef SHASH
#undef SHASH
#endif
#define SHASH(str) (gchar*)g_hash_table_lookup(config, str)

#ifdef iSHASH
#undef iSHASH
#endif
#define iSHASH(str) \
	(gint) \
	((SHASH(str) == NULL) ? 0 : \
	g_ascii_digit_value((char)(*SHASH(str))))

#ifdef setBHASH
#undef setBHASH
#endif
#define setBHASH(str, value) \
	if(SHASH(str) != NULL) { \
		g_hash_table_replace(config, str, \
			g_strdup_printf("%d", value)); \
	} else { \
		g_hash_table_insert(config, str, \
			g_strdup_printf("%d", value)); \
	}

#define COMMANDLINE "rdesktop"

#ifndef MAXHOSTNAMELEN
#define MAXHOSTNAMELEN 64		/* max length of hostname */
#endif

#define MAXHOSTS 10			/* maximum hosts to store */
#define PIXDIR DATADIR"/pixmaps/grdesktop"
#ifndef KBPATH
#define KBPATH "/usr/local/share/rdesktop/keymaps/"
#endif

#define GCONF_BASE "/apps/grdesktop/options"

GList *hostnames;
GList *rdp_protocols;
GList *screensize;
GList *colors;
GList *sound_options;
GHashTable *config;
GConfClient *gcfg;

/* these widgets are used global */
GtkWidget *window_main;
GtkWidget *image_normal;
GtkWidget *image_process;
GtkWidget *box_server;
GtkWidget *box_option;
GtkWidget *btn_connect;
GtkWidget *btn_cancel;
GtkWidget *btn_option;
GtkWidget *combo_host;
GtkWidget *combo_host2;
GtkWidget *input_username;
GtkWidget *input_password;
GtkWidget *input_domain;
GtkWidget *check_savepw;
GtkWidget *menu_rdp_proto;
GtkObject *adj_screensize;
GtkWidget *scroll_screensize;
GtkWidget *geometry_label;
GtkWidget *menu_colorsize;
GtkWidget *image_colorsize;
GtkWidget *tree_keymap;
GtkWidget *menu_sound;
GtkWidget *check_prog;
GtkWidget *input_program;
GtkWidget *input_ppath;
GtkWidget *check_bitmapupd;
GtkWidget *check_motionevt;
GtkWidget *check_hidewmdecoration;
GtkWidget *check_noencr;
GtkWidget *check_wmkeybindings;
GtkWidget *check_attconsole;
GtkWidget *combo_clientname;
GtkWidget *input_sshhost;

#endif /* __CONFIG_H__ */
